Dexterity Content — plone.jsonapi.routes 0.8.3 documentation

### Navigation

- index
- next |
- previous |
- plone.jsonapi.routes 0.8.3 documentation »

# Dexterity Content

New in version 0.7: Added Dexterity Data Manager (see: datamanagers.py)

Dexterity Content Types are handled by a Data Manager, also see Adding a custom data manager. Integrators just have to add route providers for their Dexterity Content Types (see: Adding a custom route provider) and the JSON API should handle the heavy lifting.

## Security

plone.jsonapi.routes checks only the permission on the content object to be at least cmf.ModifyPortalContent. Checks on the field level will be added in future versions.

### Navigation

- index
- next |
- previous |
- plone.jsonapi.routes 0.8.3 documentation »